@@ -78,7 +78,7 @@ class SquadObject:
         class_name = get_class_name(self)
         attrs_str = []
         for attr in self.attrs:
-            attrs_str.append('%s: "%s"' % (attr, getattr(self, attr)))
+            attrs_str.append('%s: "%s"' % (attr, getattr(self, attr) if hasattr(self, attr) else None))
 
         return '%s(%s)' % (class_name, ', '.join(attrs_str))
 
@@ -383,6 +383,14 @@ class Build(SquadObject):
 
         return testruns
 
+    __tests__ = None
+
+    def tests(self, count=ALL, **filters):
+        if self.__tests__ is None:
+            endpoint = '%s%d/tests/' % (self.endpoint, self.id)
+            self.__tests__ = self.__fetch__(Test, filters, count, endpoint=endpoint)
+        return self.__tests__
+
     __metadata__ = None
     __status__ = None
 
@@ -442,11 +450,11 @@ class MetricSuite:
 
 class Metric(SquadObject):
     endpoint = '/api/metrics/'
-    attrs = ['id', 'name', 'short_name', 'measurement_list', 'result', 'is_outlier', 'test_run', 'suite', 'metadata']
+    attrs = ['url', 'id', 'name', 'short_name', 'measurement_list', 'result', 'is_outlier', 'test_run', 'suite', 'metadata']
 
 
 class TestRunStatus(SquadObject):
-    attrs = ['id', 'tests_pass', 'tests_fail', 'tests_xfail',
+    attrs = ['url', 'id', 'tests_pass', 'tests_fail', 'tests_xfail',
              'tests_skip', 'metrics_summary', 'has_metrics',
              'suite', 'suite_version']
 
@@ -547,14 +555,14 @@ class TestRun(SquadObject):
 class Test(SquadObject):
 
     endpoint = '/api/tests/'
-    attrs = ['id', 'name', 'short_name', 'status', 'result', 'test_run', 'log', 'has_known_issues',
+    attrs = ['url', 'id', 'name', 'short_name', 'status', 'result', 'test_run', 'log', 'has_known_issues',
              'suite', 'known_issues']
 
 
 class Suite(SquadObject):
 
     endpoint = '/api/suites/'
-    attrs = ['id', 'slug', 'name', 'project']
+    attrs = ['url', 'id', 'slug', 'name', 'project']
 
     __tests__ = None
 
@@ -598,13 +606,13 @@ class KnownIssue(SquadObject):
 class SuiteMetadata(SquadObject):
 
     endpoint = '/api/suitemetadata/'
-    attrs = ['id', 'name', 'suite', 'kind', 'description', 'instructions_to_reproduce']
+    attrs = ['url', 'id', 'name', 'suite', 'kind', 'description', 'instructions_to_reproduce']
 
 
 class Annotation(SquadObject):
 
     endpoint = '/api/annotations/'
-    attrs = ['id', 'description', 'build']
+    attrs = ['url', 'id', 'description', 'build']
 
 
 class MetricThreshold(SquadObject):
